@@ -46,8 +46,8 @@ class SoftDeterministicPolicyNetwork(RLNetwork):
         return self._squash(normal.loc)
 
     def _normal(self, outputs):
-        means = outputs[:, 0:self._action_dim]
-        logvars = outputs[:, self._action_dim:]
+        means = outputs[..., 0:self._action_dim]
+        logvars = outputs[..., self._action_dim:]
         std = logvars.mul(0.5).exp_()
         return torch.distributions.normal.Normal(means, std)
 
@@ -74,7 +74,7 @@ class SoftDeterministicPolicyNetwork(RLNetwork):
         log_prob = normal.log_prob(raw)
         log_prob -= torch.log(1 - torch.tanh(raw).pow(2) + 1e-6)
         log_prob /= self._tanh_scale
-        return log_prob.sum(1)
+        return log_prob.sum(-1)
 
     def _squash(self, x):
         return torch.tanh(x) * self._tanh_scale + self._tanh_mean
