@@ -14,7 +14,7 @@ class TestContinuousPresets(unittest.TestCase):
         self.validate(sac(replay_start_size=50, device='cpu'))
 
     def validate(self, make_agent):
-        validate_agent(make_agent, GymEnvironment('Pendulum-v0'))
+        validate_agent(make_agent, GymEnvironment('LunarLanderContinuous-v2'))
 
 if __name__ == '__main__':
     unittest.main()
